import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 * @stability stable
 */
export interface AppmeshVirtualNodeConfig extends TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly meshName: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * spec block.
     *
     * @stability stable
     */
    readonly spec: AppmeshVirtualNodeSpec[];
}
/**
 * @stability stable
 */
export interface AppmeshVirtualNodeSpecBackendVirtualService {
    /**
     * @stability stable
     */
    readonly virtualServiceName: string;
}
/**
 * @stability stable
 */
export interface AppmeshVirtualNodeSpecBackend {
    /**
     * virtual_service block.
     *
     * @stability stable
     */
    readonly virtualService?: AppmeshVirtualNodeSpecBackendVirtualService[];
}
/**
 * @stability stable
 */
export interface AppmeshVirtualNodeSpecListenerHealthCheck {
    /**
     * @stability stable
     */
    readonly healthyThreshold: number;
    /**
     * @stability stable
     */
    readonly intervalMillis: number;
    /**
     * @stability stable
     */
    readonly path?: string;
    /**
     * @stability stable
     */
    readonly port?: number;
    /**
     * @stability stable
     */
    readonly protocol: string;
    /**
     * @stability stable
     */
    readonly timeoutMillis: number;
    /**
     * @stability stable
     */
    readonly unhealthyThreshold: number;
}
/**
 * @stability stable
 */
export interface AppmeshVirtualNodeSpecListenerPortMapping {
    /**
     * @stability stable
     */
    readonly port: number;
    /**
     * @stability stable
     */
    readonly protocol: string;
}
/**
 * @stability stable
 */
export interface AppmeshVirtualNodeSpecListener {
    /**
     * health_check block.
     *
     * @stability stable
     */
    readonly healthCheck?: AppmeshVirtualNodeSpecListenerHealthCheck[];
    /**
     * port_mapping block.
     *
     * @stability stable
     */
    readonly portMapping: AppmeshVirtualNodeSpecListenerPortMapping[];
}
/**
 * @stability stable
 */
export interface AppmeshVirtualNodeSpecLoggingAccessLogFile {
    /**
     * @stability stable
     */
    readonly path: string;
}
/**
 * @stability stable
 */
export interface AppmeshVirtualNodeSpecLoggingAccessLog {
    /**
     * file block.
     *
     * @stability stable
     */
    readonly file?: AppmeshVirtualNodeSpecLoggingAccessLogFile[];
}
/**
 * @stability stable
 */
export interface AppmeshVirtualNodeSpecLogging {
    /**
     * access_log block.
     *
     * @stability stable
     */
    readonly accessLog?: AppmeshVirtualNodeSpecLoggingAccessLog[];
}
/**
 * @stability stable
 */
export interface AppmeshVirtualNodeSpecServiceDiscoveryAwsCloudMap {
    /**
     * @stability stable
     */
    readonly attributes?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly namespaceName: string;
    /**
     * @stability stable
     */
    readonly serviceName: string;
}
/**
 * @stability stable
 */
export interface AppmeshVirtualNodeSpecServiceDiscoveryDns {
    /**
     * @stability stable
     */
    readonly hostname: string;
    /**
     * @stability stable
     */
    readonly serviceName?: string;
}
/**
 * @stability stable
 */
export interface AppmeshVirtualNodeSpecServiceDiscovery {
    /**
     * aws_cloud_map block.
     *
     * @stability stable
     */
    readonly awsCloudMap?: AppmeshVirtualNodeSpecServiceDiscoveryAwsCloudMap[];
    /**
     * dns block.
     *
     * @stability stable
     */
    readonly dns?: AppmeshVirtualNodeSpecServiceDiscoveryDns[];
}
/**
 * @stability stable
 */
export interface AppmeshVirtualNodeSpec {
    /**
     * @stability stable
     */
    readonly backends?: string[];
    /**
     * backend block.
     *
     * @stability stable
     */
    readonly backend?: AppmeshVirtualNodeSpecBackend[];
    /**
     * listener block.
     *
     * @stability stable
     */
    readonly listener?: AppmeshVirtualNodeSpecListener[];
    /**
     * logging block.
     *
     * @stability stable
     */
    readonly logging?: AppmeshVirtualNodeSpecLogging[];
    /**
     * service_discovery block.
     *
     * @stability stable
     */
    readonly serviceDiscovery?: AppmeshVirtualNodeSpecServiceDiscovery[];
}
/**
 * @stability stable
 */
export declare class AppmeshVirtualNode extends TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: AppmeshVirtualNodeConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    get createdDate(): string;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get lastUpdatedDate(): string;
    private _meshName;
    /**
     * @stability stable
     */
    get meshName(): string;
    /**
     * @stability stable
     */
    set meshName(value: string);
    /**
     * @stability stable
     */
    get meshNameInput(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _spec;
    /**
     * @stability stable
     */
    get spec(): AppmeshVirtualNodeSpec[];
    /**
     * @stability stable
     */
    set spec(value: AppmeshVirtualNodeSpec[]);
    /**
     * @stability stable
     */
    get specInput(): AppmeshVirtualNodeSpec[];
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
