import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 * @stability stable
 */
export interface FsxLustreFileSystemConfig extends TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly exportPath?: string;
    /**
     * @stability stable
     */
    readonly importPath?: string;
    /**
     * @stability stable
     */
    readonly importedFileChunkSize?: number;
    /**
     * @stability stable
     */
    readonly securityGroupIds?: string[];
    /**
     * @stability stable
     */
    readonly storageCapacity: number;
    /**
     * @stability stable
     */
    readonly subnetIds: string[];
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly weeklyMaintenanceStartTime?: string;
    /**
     * timeouts block.
     *
     * @stability stable
     */
    readonly timeouts?: FsxLustreFileSystemTimeouts;
}
/**
 * @stability stable
 */
export interface FsxLustreFileSystemTimeouts {
    /**
     * @stability stable
     */
    readonly create?: string;
    /**
     * @stability stable
     */
    readonly delete?: string;
}
/**
 * @stability stable
 */
export declare class FsxLustreFileSystem extends TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: FsxLustreFileSystemConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    get dnsName(): string;
    private _exportPath?;
    /**
     * @stability stable
     */
    get exportPath(): string;
    /**
     * @stability stable
     */
    set exportPath(value: string);
    /**
     * @stability stable
     */
    resetExportPath(): void;
    /**
     * @stability stable
     */
    get exportPathInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _importPath?;
    /**
     * @stability stable
     */
    get importPath(): string;
    /**
     * @stability stable
     */
    set importPath(value: string);
    /**
     * @stability stable
     */
    resetImportPath(): void;
    /**
     * @stability stable
     */
    get importPathInput(): string | undefined;
    private _importedFileChunkSize?;
    /**
     * @stability stable
     */
    get importedFileChunkSize(): number;
    /**
     * @stability stable
     */
    set importedFileChunkSize(value: number);
    /**
     * @stability stable
     */
    resetImportedFileChunkSize(): void;
    /**
     * @stability stable
     */
    get importedFileChunkSizeInput(): number | undefined;
    /**
     * @stability stable
     */
    get networkInterfaceIds(): string[];
    /**
     * @stability stable
     */
    get ownerId(): string;
    private _securityGroupIds?;
    /**
     * @stability stable
     */
    get securityGroupIds(): string[];
    /**
     * @stability stable
     */
    set securityGroupIds(value: string[]);
    /**
     * @stability stable
     */
    resetSecurityGroupIds(): void;
    /**
     * @stability stable
     */
    get securityGroupIdsInput(): string[] | undefined;
    private _storageCapacity;
    /**
     * @stability stable
     */
    get storageCapacity(): number;
    /**
     * @stability stable
     */
    set storageCapacity(value: number);
    /**
     * @stability stable
     */
    get storageCapacityInput(): number;
    private _subnetIds;
    /**
     * @stability stable
     */
    get subnetIds(): string[];
    /**
     * @stability stable
     */
    set subnetIds(value: string[]);
    /**
     * @stability stable
     */
    get subnetIdsInput(): string[];
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    get vpcId(): string;
    private _weeklyMaintenanceStartTime?;
    /**
     * @stability stable
     */
    get weeklyMaintenanceStartTime(): string;
    /**
     * @stability stable
     */
    set weeklyMaintenanceStartTime(value: string);
    /**
     * @stability stable
     */
    resetWeeklyMaintenanceStartTime(): void;
    /**
     * @stability stable
     */
    get weeklyMaintenanceStartTimeInput(): string | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): FsxLustreFileSystemTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: FsxLustreFileSystemTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): FsxLustreFileSystemTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
